==> 0.0.14.tar.gz: lib/src/package_loader.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_svg/flutter_svg.dart';

import './virtual_bundle.dart';

class PackageLoader {
  AssetBundle _bundle;
  String _package;

  static String _packageAsBundle;

  String _rkey(String key) => asBundle ? key : "packages/$_package/$key";

  AssetBundle get bundle => _bundle;

  bool get asBundle => _packageAsBundle == _package;

  String get package => asBundle ? null : _package;

  String resolve(String key) => _rkey(key);

  PackageLoader(this._package, [this._bundle]) {
    if (this._package == null) throw Exception("package required!");
    if (this._bundle == null) this._bundle = virtualBundle;
  }

  static void main(String pkg) {
    _packageAsBundle = pkg;
  }

  Future<ByteData> load(String key) {
    return this.bundle.load(_rkey(key));
  }

  Future<String> loadString(String key, {bool cache = true}) async {
    return this.bundle.loadString(_rkey(key), cache: cache);
  }

  Future<T> loadStructuredData<T>(String key, Future<T> parser(String value)) {
    return this.bundle.loadStructuredData<T>(_rkey(key), parser);
  }

  Future<dynamic> loadJson(String key, {bool cache = true}) async {
    final source = await loadString(key, cache: cache);
    return Future.value(json.decode(source));
  }

  Future<void> loadFont(String family, String key) async {
    final fontLoader = FontLoader(family);
    fontLoader.addFont(load(key));
    return fontLoader.load();
  }

  Image loadImage(
    String name, {
    Key key,
    double scale,
    String semanticLabel,
    bool excludeFromSemantics = false,
    double width,
    double height,
    Color color,
    BlendMode colorBlendMode,
    BoxFit fit,
    Alignment alignment = Alignment.center,
    ImageRepeat repeat = ImageRepeat.noRepeat,
    Rect centerSlice,
    bool matchTextDirection = false,
    bool gaplessPlayback = false,
    FilterQuality filterQuality = FilterQuality.low,
  }) {
    return Image.asset(name,
        key: key,
        bundle: this.bundle,
        package: this.package,
        semanticLabel: semanticLabel,
        excludeFromSemantics: excludeFromSemantics,
        scale: scale,
        width: width,
        height: height,
        color: color,
        colorBlendMode: colorBlendMode,
        fit: fit,
        alignment: alignment,
        repeat: repeat,
        centerSlice: centerSlice,
        matchTextDirection: matchTextDirection,
        gaplessPlayback: gaplessPlayback,
        filterQuality: filterQuality);
  }

  SvgPicture loadSvg(String assetName,
      {Key key,
      bool matchTextDirection: false,
      double width,
      double height,
      BoxFit fit: BoxFit.contain,
      Alignment alignment: Alignment.center,
      bool allowDrawingOutsideViewBox: false,
      WidgetBuilder placeholderBuilder,
      Color color,
      BlendMode colorBlendMode: BlendMode.srcIn,
      String semanticsLabel,
      bool excludeFromSemantics: false}) {
    return SvgPicture.asset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: this.bundle,
      package: this.package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
    );
  }

  AssetImage loadAssetImage(String assetName) {
    return AssetImage(assetName, bundle: this.bundle, package: this.package);
  }
}

==> 0.0.18.tar.gz: lib/src/package_loader.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_svg/flutter_svg.dart';

import './virtual_bundle.dart';

class PackageLoader {
  AssetBundle? _bundle;
  String? _package;

  static String? _packageAsBundle;

  String _rkey(String key) => asBundle ? key : "packages/$_package/$key";

  AssetBundle? get bundle => _bundle;

  bool get asBundle => _packageAsBundle == _package;

  String? get package => asBundle ? null : _package;

  String resolve(String key) => _rkey(key);

  PackageLoader(this._package, [this._bundle]) {
    if (this._package == null) throw Exception("package required!");
    if (this._bundle == null) this._bundle = virtualBundle;
  }

  static void main(String pkg) {
    _packageAsBundle = pkg;
  }

  Future<ByteData> load(String key) {
    return this.bundle!.load(_rkey(key));
  }

  Future<String> loadString(String key, {bool cache = true}) async {
    return this.bundle!.loadString(_rkey(key), cache: cache);
  }

  Future<T> loadStructuredData<T>(String key, Future<T> parser(String value)) {
    return this.bundle!.loadStructuredData<T>(_rkey(key), parser);
  }

  Future<dynamic> loadJson(String key, {bool cache = true}) async {
    final source = await loadString(key, cache: cache);
    return Future.value(json.decode(source));
  }

  Future<void> loadFont(String family, String key) async {
    final fontLoader = FontLoader(family);
    fontLoader.addFont(load(key));
    return fontLoader.load();
  }

  Image loadImage(
    String name, {
    Key? key,
    double? scale,
    String? semanticLabel,
    bool excludeFromSemantics = false,
    double? width,
    double? height,
    Color? color,
    BlendMode? colorBlendMode,
    BoxFit? fit,
    Alignment alignment = Alignment.center,
    ImageRepeat repeat = ImageRepeat.noRepeat,
    Rect? centerSlice,
    bool matchTextDirection = false,
    bool gaplessPlayback = false,
    FilterQuality filterQuality = FilterQuality.low,
  }) {
    return Image.asset(name,
        key: key,
        bundle: this.bundle,
        package: this.package,
        semanticLabel: semanticLabel,
        excludeFromSemantics: excludeFromSemantics,
        scale: scale,
        width: width,
        height: height,
        color: color,
        colorBlendMode: colorBlendMode,
        fit: fit,
        alignment: alignment,
        repeat: repeat,
        centerSlice: centerSlice,
        matchTextDirection: matchTextDirection,
        gaplessPlayback: gaplessPlayback,
        filterQuality: filterQuality);
  }

  SvgPicture loadSvg(String assetName,
      {Key? key,
      bool matchTextDirection: false,
      double? width,
      double? height,
      BoxFit fit: BoxFit.contain,
      Alignment alignment: Alignment.center,
      bool allowDrawingOutsideViewBox: false,
      WidgetBuilder? placeholderBuilder,
      Color? color,
      BlendMode colorBlendMode: BlendMode.srcIn,
      String? semanticsLabel,
      bool excludeFromSemantics: false}) {
    return SvgPicture.asset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: this.bundle,
      package: this.package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
    );
  }

  AssetImage loadAssetImage(String assetName) {
    return AssetImage(assetName, bundle: this.bundle, package: this.package);
  }
}
